function [] = aggregate_feature_folder(data_dir,dataset_name,out_dir,num_bins)
%AGGREGATE_FEATURE_FOLDER_SINGLE Summary of this function goes here

image_features = read_features_dir(strcat(data_dir,dataset_name),'Pami');

image_data  = vertcat(image_features{:});

unique_subjects = unique(image_data(:,1));
unique_stimuli  = unique(image_data(:,2));

bin_data  = zeros(size(image_data));

num_features  = size(image_data,2);

feature_bins  = cell(num_features,1);

feature_names  = {"subject_id","stimulus_id"};

bin_data(:,1)  = image_data(:,1);
bin_data(:,2)  = image_data(:,2);

for i = 3:num_features
    [curr_bin_data,curr_edges]   = discretize(image_data(:,i),num_bins);
    
    curr_feature_name = strcat("pami_",num2str(i-2));
    
    bin_data(:,i)    = curr_bin_data;
    feature_bins{i}  = curr_edges; 
    feature_names{i} = curr_feature_name;
    
end

%make the output folder and folder for each feature type
mkdir(strcat(out_dir,'\',dataset_name,'_pd\'));
mkdir(strcat(out_dir,'\',dataset_name,'_pd\','pami\'));

%save attrs and grps
out_attrs_str  = strcat(out_dir,'\',dataset_name,'_pd\','pami\pami_attrs.csv');
out_grps_str  = strcat(out_dir,'\',dataset_name,'_pd\','pami\pami_grps.csv');

fid_attrs = fopen( out_attrs_str, 'w' );
fid_grps  = fopen( out_grps_str, 'w' );

for i = 1:num_features
   attrs_out_row_str = feature_names{i};
   grps_out_row_str  = "";
   %if i == 1, this is subject row, write the name and then the uniques for attrs
   if (i ==1)
       for j = 1:length(unique_subjects)
           attrs_out_row_str = strcat(attrs_out_row_str,',',num2str(unique_subjects(j)));
           if (j == 1)
               grps_out_row_str  = num2str(unique_subjects(j));
           else
               grps_out_row_str  = strcat(grps_out_row_str,',',num2str(unique_subjects(j)));
           end
       end
       
   %if i == 2, this is stimulus row, write the name and then the uniques for attrs
   elseif (i == 2)
       for j = 1:length(unique_stimuli)
           attrs_out_row_str = strcat(attrs_out_row_str,',',num2str(unique_stimuli(j)));
           if (j == 1)
               grps_out_row_str  = num2str(unique_stimuli(j));
           else
               grps_out_row_str  = strcat(grps_out_row_str,',',num2str(unique_stimuli(j)));
           end
       end
       
   %for all others, write the name and then add the numbers through # bins
   else
       for j = 1:num_bins
           attrs_out_row_str = strcat(attrs_out_row_str,',',num2str(j));
           if (j == 1)
               grps_out_row_str  = num2str(j);
           else
               grps_out_row_str  = strcat(grps_out_row_str,',',num2str(j));
           end
       end
   end   
   fprintf(fid_attrs,strcat(attrs_out_row_str,'\n'));
   fprintf(fid_grps,strcat(grps_out_row_str,'\n'));
end

fclose( fid_attrs );
fclose( fid_grps );

%save the edges/bins for later resampling 
out_bins_str  = strcat(out_dir,'\',dataset_name,'_pd\','pami_bins.csv');

fid_bins = fopen( out_bins_str, 'w' );

%loop through each feature (row) and write out the edges
for i = 3:num_features
    out_row = num2str(feature_bins{i},'%.5f,');

    %remove trailing comma and write line
	fprintf(fid_bins,strcat(out_row(1:end-1),'\n'));
end

fclose(fid_bins);

%output matching format for SGF codebase
out_dag_str    = strcat(out_dir,'\',dataset_name,'_pd\','pami\pami_dag.csv');
out_order_str  = strcat(out_dir,'\',dataset_name,'_pd\','pami\pami_order.csv');

fid_dag   = fopen( out_dag_str, 'w' );
fid_order = fopen( out_order_str, 'w' );

for i = 1:num_features
	out_row_dag   = "";
    out_row_order = "";
    
	%if i == 1, this is subject row
	if (i ==1)
	   out_row_dag   = "0";
       out_row_order = num2str(1);
	%if i == 2, this is stimulus row
	elseif (i == 2)
	   out_row_dag   = "0";
       out_row_order = num2str(2);
    else
       out_row_dag   = "1,2,0.1";
       out_row_order = num2str(i);
	end   
	fprintf(fid_dag,strcat(out_row_dag,'\n'));
    fprintf(fid_order,strcat(out_row_order,'\n'));
end

fclose(fid_dag);
fclose(fid_order);

out_data_str  = strcat(out_dir,'\',dataset_name,'_pd\','pami\pami_records.csv');
csvwrite(out_data_str,bin_data);

out_data_str  = strcat(out_dir,'\',dataset_name,'_pd\','pami\pami_stats.csv');
csvwrite(out_data_str,bin_data);



end

