import numpy as np
import os
from numpy.random import default_rng

#credit: https://askdevz.com/question/595309-sampling-unique-column-indexes-for-each-row-of-a-numpy-array
def random_unique_indexes_per_row(A, N=1):
    m, n = A.shape
    return np.random.rand(m, n).argsort(1)[:, :N]


def exponential_mechanism(X, deltas, epsilons, w, t_max):
    #if subsampling windows
    if w != 1:
        # enforce rows are a multiple of w
        num_rows = (X.shape[0] // w) * w
        row_idx = np.arange(0, num_rows)

        row_idx = row_idx.reshape((-1, w))
        rand_col_idx = random_unique_indexes_per_row(row_idx, 1)

        # grab one of the w elements in each window based on rand_col_idx
        sub_idx = row_idx[np.arange(0, row_idx.shape[0]), rand_col_idx.ravel()]

        #subsampled data
        X_sub = X[sub_idx, :]

    #else: not subsampling
    else:
        X_sub = X

    # scale lambdas by w param to adjust sensitivity
    lambdas = (w * epsilons) / (2 * t_max * deltas)

    #random sample y values all at once, then spread along rows, as paper suggests
    scales = 1 / lambdas

    rng = default_rng()
    y = rng.exponential(scale=scales)

    r_vals = np.log(y) / (lambdas * t_max)

    #generate matrix that is same size as X, with ln(y)/(lambdas*t_max) repeated along rows
    r = np.repeat(r_vals.reshape(1, -1), X_sub.shape[0], axis=0)

    #randomly flip signs
    r_sign_multiplier = 2 * np.random.randint(0, 2, size=(r.shape)) - 1
    r = r * r_sign_multiplier

    return X_sub + r


def save_dict(out_dataset_path, feature, private_data_dict):
    # if doesn't exist make it
    if not os.path.isdir(out_dataset_path):
        os.makedirs(out_dataset_path)

    # Loop through each img
    for img in private_data_dict.keys():
        curr_img_data = private_data_dict[img]

        # separate out the sub_id col
        sub_ids = curr_img_data[:, 0]
        curr_img_data = curr_img_data[:, 1:]

        # extract the unique subjects from with this dict data entry
        unique_sub_ids = np.unique(sub_ids)

        for sub_id in unique_sub_ids:
            sub_idx = sub_ids == sub_id
            curr_sub_data = curr_img_data[sub_idx, :]

            out_file = 'Data_P' + str(int(sub_id)) + '_R' + str(img) + '_' + feature + '.csv'

            # write out
            np.savetxt(os.path.join(out_dataset_path, out_file), curr_sub_data, delimiter=",")