function [] = reconstruct_feature_folder_task(data_dir,dataset_name,task_id,out_dir)
% read in the k/gamma parameters for data_dir
[k_params,gamma_params] = read_pd_params(data_dir,dataset_name);

%read in the clean feature data to get number of features per subject per stimulus 
%some sort of dict, main index is img_idx, and then in that a cellarray with inputs for sub_id storing number of features
%rows are stimulus_idx and cols are sub_ids
clean_features = read_num_features_dir(strcat(out_dir,dataset_name,'_clean'),'Pami');

%loop through each param 
for i = 1:length(k_params)
    k_param     = k_params(i);
    gamma_param = gamma_params(i);
    
	%make output folder in out_dir, use dataset_name and params
    curr_out_dir = strcat(out_dir,dataset_name,'_pd_k_',num2str(k_param),...
                         '_gamma_',num2str(gamma_param));
    mkdir(curr_out_dir);

    curr_pd_dir = strcat(data_dir,dataset_name,'_k_',num2str(k_param),'_gamma_',num2str(gamma_param));
    
    img_col = 2;
    sub_col = 1; 
    
	%load the synth data 
	data  = csvread(strcat(curr_pd_dir,'/pami.synth'),1,0);
    
	unique_subjects = unique(data(:,sub_col));
	unique_stimuli  = unique(data(:,img_col));
    
    sub_labels        = data(:,sub_col);
    stimulus_labels   = data(:,img_col);

	feature_out_dir = strcat(curr_out_dir,'\');

	%loop through subjects
    %for unique subjects
    for s = 1:length(unique_subjects)
        curr_sub =  unique_subjects(s);
        
		%loop through stimulus 
        for j = 1:length(unique_stimuli)
            curr_stimulus = unique_stimuli(j);
			
            %only process if this stimulus matches task_id
            if curr_stimulus ~= task_id
               continue; 
            end
            
            num_rows_sample  = clean_features{curr_stimulus,curr_sub};
            
            %if either are empty, skip
            if isempty(num_rows_sample) 
                continue
            end
            
			%get subset of the dataset for this subject and stimulus 
            curr_idx = find((sub_labels == curr_sub)&(stimulus_labels == curr_stimulus));
            
            %if no synthetic matches, skip
            if (isempty(curr_idx))
               continue 
            end

            %idx 1 and 2 are the subject id and img id
            curr_data = data(curr_idx,3:end);

            num_total_rows  = size(curr_data,1);
            
            if (num_total_rows < num_rows_sample)
                %pad curr_fix_data with repeats

                num_pad_rows_needed = num_rows_sample - num_total_rows;
                
                %pad rows of curr_data by repeating last 
                curr_data = padarray(curr_data,num_pad_rows_needed,'replicate','post');
                num_total_rows  = size(curr_data,1);
            end
            
			%in here randomly pick number of rows equal to number from clean data set 
			curr_data  = curr_data( randperm(num_total_rows,num_rows_sample),:);
            
            
			%use the bin idx to get edges for the clean dataset, and sample
			%within the range for each row
            
            %read in the edges
            edges  = csvread(strcat(data_dir,dataset_name,'_clean_pd\pami_bins.csv'));
			
            %the synthetic data values are all look ups into the
            %rows of features in fix_edges, each feature col in data 
            %correspond to a row of edge/bin values
            
            num_features  = size(curr_data,2);
            
            for k = 1:num_features 
               %edges are the ranges to sample from
               curr_edges = edges(k,:);
               
               %bins are which range to sample from
               curr_bins = curr_data(:,k);
               num_bins  = length(curr_edges)-1;
               
               %want vector same size as curr_bins (num_fix_rows_sample)
               %with newly sampled numbers
               
               %create matrix where columns are bins sampled from
               %with number of rows equal to num_fix_rows_sample
               rand_vals = zeros(num_rows_sample,num_bins);
               
               for b = 1:num_bins
                  rand_vals(:,b) = unifrnd(curr_edges(b),curr_edges(b+1),num_rows_sample,1);
               end
               
               %one hot encode with booleans for indexing cols of rand_vals
               curr_bins_logical = curr_bins == 1:num_bins;
               
               curr_data(:,k) = rand_vals(curr_bins_logical);
            end
            
			%write out the sampled data to standard csv format (just
			%features, no sub/stim as that will be in the file name)
			
			%Data_P#_R#_Pami_Features_52.csv
			features_out_str = strcat(feature_out_dir,'Data_P',num2str(curr_sub),'_R',num2str(curr_stimulus),'_Pami_Features_52.csv');
            
            %save out reconstructued data for this sub/stim
            csvwrite(features_out_str,curr_data);
        end
    end
end

end

